@@ -24,6 +24,7 @@ from setuptools_scm import integration
 from setuptools_scm import NonNormalizedVersion
 from setuptools_scm.file_finder_git import git_find_files
 from setuptools_scm.git import archival_to_version
+from setuptools_scm.utils import data_from_mime
 from setuptools_scm.utils import do
 from setuptools_scm.utils import has_command
 
@@ -543,3 +544,14 @@ def test_git_archival_node_missing_no_version() -> None:
     config = Configuration()
     version = archival_to_version({}, config=config)
     assert version is None
+
+
+def test_git_archhival_from_unfiltered() -> None:
+    config = Configuration()
+
+    import setuptools_scm
+
+    data = data_from_mime(Path(setuptools_scm.__file__).parent / ".git_archival.txt")
+    with pytest.warns(UserWarning, match="unexported git archival found"):
+        version = archival_to_version(data, config=config)
+    assert version is None
